# Slot: inverse


used to indicate the inverse of a slot (e.g. 'expresses' is the inverse predicate of 'expressed in')

URI: [http://w3id.org/biolink/biolinkml/meta/inverse](slot_uri)
## Domain and Range

[SlotDefinition](SlotDefinition.md) -><sub>opt</sub> [SlotDefinition](SlotDefinition.md)
## Inheritance

## Children

## Used by

 * [SlotDefinition](SlotDefinition.md)
